struct Hole<'a, T: 'a> {
data: &'a mut [T],
elt: ManuallyDrop<T>,
pos: usize,
}Expand description
Hole represents a hole in a slice i.e., an index without valid value
(because it was moved from or duplicated).
In drop, Hole will restore the slice by filling the hole
position with the value that was originally removed.
Fields
data: &'a mut [T]elt: ManuallyDrop<T>pos: usizeImplementations
Sourceimpl<'a, T> Hole<'a, T>
impl<'a, T> Hole<'a, T>
Sourceunsafe fn new(data: &'a mut [T], pos: usize) -> Self
unsafe fn new(data: &'a mut [T], pos: usize) -> Self
Creates a new Hole at index pos.
Unsafe because pos must be within the data slice.
fn pos(&self) -> usize